@@ -8,7 +8,6 @@ import re
 
 import flask
 import flask.views
-from flask import request
 from volkanic.utils import merge_dicts
 
 
@@ -69,6 +68,7 @@ def respond_xaccel_redirect(path: str, filename: str = None):
 
 
 def get_request_data(force_json=False):
+    request = flask.request
     if request.method == 'GET':
         return request.args.to_dict()
     if force_json or request.is_json:
@@ -99,9 +99,9 @@ class ReducedRestfulView(flask.views.MethodView, _ReducedViewMixin):
     pass
 
 
-def jsonp(resp, callback):
+def jsonp(data, callback):
     return flask.current_app.response_class(
-        callback + '(' + flask.json.dumps(resp) + ');\n',
+        callback + '(' + flask.json.dumps(data) + ');\n',
         mimetype='application/javascript'
     )
 
@@ -170,3 +170,19 @@ def is_mobile():
     )
     ua = flask.request.headers.get('User-Agent', '')
     return _regex_ua_mobile.search(ua)
+
+
+def is_wechat():
+    return 'micromessenger' in flask.request.user_agent.string.lower()
+
+
+def decorate_all_view_funcs(app, decorator):
+    keys = list(app.view_functions)
+    for key in keys:
+        func = app.view_functions[key]
+        app.view_functions[key] = decorator(func)
+
+
+def url_for_this(**values):
+    # https://github.com/pallets/flask/issues/2111
+    return flask.url_for(flask.request.endpoint, **values)
